@@ -28,8 +28,10 @@ class MachineLearningModel(object):
         #     message = f"Machine learning model at {path} not exists!"
         #     logger.error(message)
         #     raise FileNotFoundError(message)
+        package_dir = os.path.dirname(os.path.abspath(__file__))
+        print(package_dir)
         mypath = path("tqatest.ml.model", "TrainedModel_c++.ann")
-        self.load_model(str(mypath))
+        # self.load_model(str(mypath))
     
     def load_model(self, mypath : str):
         self.model = annhub.ANNHUB(int(MODEL_ID))
